@@ -2,8 +2,8 @@
 
 ;; Author: Colin McLear <mclear@fastmail.com>
 ;; Maintainer: Colin McLear
-;; Package-Version: 20251108.1927
-;; Package-Revision: 8873c46da96c
+;; Package-Version: 20260206.225
+;; Package-Revision: 3b801a7cc698
 ;; Package-Requires: ((emacs "27.1") (project "0.8.1"))
 ;; Keywords: convenience, frames
 ;; Homepage: https://github.com/mclear-tools/tabspaces
@@ -599,6 +599,9 @@ If FRAME is nil, use the current frame."
   (let ((buf (tabspaces--buffer-list)))
     (unwind-protect
         (cl-loop for b in buf
+                 for n = (buffer-name b)
+                 unless (or (member n tabspaces-exclude-buffers)
+                            (member n tabspaces-include-buffers))
                  do (kill-buffer b))
       (tab-bar-close-tab))))
 
@@ -721,6 +724,13 @@ With universal argument PREFIX, always create a new tab for the project."
 
     (message "Tabspaces: Project directory: %s" project-directory)
 
+    ;; Remember project if it exists on disk but is not yet registered
+    (let ((pr (and (not project-exists)
+                   (project--find-in-directory project-directory))))
+      (when pr
+        (project-remember-project pr)
+        (setq project-exists t)))
+
     ;; Now manage the workspace based on the project state:
     (cond
      ;; If there is no tab nor project, create both
